# Reference

Technical reference for all TMDBFusion modules.

## Main Components

* [**Client**](_client.md)
* [**Exceptions**](exceptions.md)
* [**Pagination**](pagination.md)
* [**Core Components**](index.md) (Client, Transport, Config)
* [**API Resources**](api/index.md) (Movies, TV, People, etc.)
* [**Data Models**](models/overview.md) (Response structures)
* [**Utilities**](utils.md)
